.. _astrodynx.twobody:

``astrodynx.twobody``
=====================

.. currentmodule:: astrodynx.twobody

.. container:: module-header

   .. automodule:: astrodynx.twobody
      :no-index:

.. container:: module-content

   .. rubric:: Lagrange Coefficients

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      lagrange_F
      lagrange_G
      lagrange_Ft
      lagrange_Gt

   .. rubric:: State Transition Functions

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      prpr0
      prpv0
      pvpr0
      pvpv0
      dxdx0
      C_func

   .. rubric:: Universal Anomaly Functions

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      sigma_fn
      ufunc0
      ufunc1
      ufunc2
      ufunc3
      ufunc4
      ufunc5

   .. rubric:: Path and Trajectory Analysis

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      nmax_by_periapsis
      is_short_way
      pass_perigee
      rp_islower_rmin


.. container:: module-footer

   .. rubric:: Module Information

   **Full name:** ``astrodynx.twobody``

   **Source:** `View source on GitHub <https://github.com/adxorg/astrodynx/blob/main/src/astrodynx/twobody>`_
